# pypacm package manager

```
Basic Python CLI package manager script inspired by the Arch Linux pacman. Please report any bugs!
```
#
### Installation

- In the pypacm directory type `pip install .` or type `pip install pypacm` in command prompt

#
### Usage

1. Open `pypacm` anywhere using `Command Prompt`
2. Find and `Uninstall/Install` any of the installed packages